@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.22';
+$Net::Kubernetes::VERSION = '0.23';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -133,7 +133,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -273,7 +273,7 @@ L<Net::Kubernetes::Resource|Net::Kubernetes::Resource>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher Pruden Dave Mueller
+=for stopwords Christopher Pruden Dave Mueller Kevin Johnson
 
 =over 4
 
@@ -289,6 +289,10 @@ Dave <dave@perljedi.com>
 
 Dave Mueller <dmueller@liquidweb.com>
 
+=item *
+
+Kevin Johnson <kcavemanj@gmail.com>
+
 =back
 
 =cut
