@@ -1,6 +1,6 @@
 package Net::Kubernetes::Resource;
 # ABSTRACT: Base class for all Net::Kubernetes::Resource objects.
-$Net::Kubernetes::Resource::VERSION = '0.22';
+$Net::Kubernetes::Resource::VERSION = '0.23';
 use Moose;
 
 with 'Net::Kubernetes::Role::APIAccess';
@@ -46,6 +46,11 @@ sub update {
 sub as_hashref
 {
 	my($self) = @_;
+
+        # It is possible for kuberentes to churn the resource version higher even if 
+        # you just refresh it and then attempt an update operation. Let's ignore it for now.
+        my $metadata = $self->metadata;
+        delete $metadata->{resourceVersion};
 	
 	return {
 		inner(),
@@ -69,7 +74,7 @@ Net::Kubernetes::Resource - Base class for all Net::Kubernetes::Resource objects
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 METHODS
 
